@@ -1,8 +1,10 @@
 package Crypt::Passphrase;
-$Crypt::Passphrase::VERSION = '0.012';
+$Crypt::Passphrase::VERSION = '0.013';
 use strict;
 use warnings;
 
+use mro ();
+
 use Carp ();
 use Scalar::Util ();
 use Encode ();
@@ -17,15 +19,15 @@ sub import {
 			require Crypt::Passphrase::Encoder;
 			no strict 'refs';
 			no warnings 'once';
-			push @{"$caller\::ISA"}, 'Crypt::Passphrase::Encoder';
-			push @{"$caller\::CARP_NOT"}, __PACKAGE__;
+			push @{"$caller\::ISA"}, 'Crypt::Passphrase::Encoder' unless $caller->isa('Crypt::Passphrase::Encoder');
+			push @{"$caller\::CARP_NOT"}, __PACKAGE__, mro::get_linear_isa($caller);
 		}
 		elsif ($arg eq '-validator') {
 			require Crypt::Passphrase::Validator;
 			no strict 'refs';
 			no warnings 'once';
-			push @{"$caller\::ISA"}, 'Crypt::Passphrase::Validator';
-			push @{"$caller\::CARP_NOT"}, __PACKAGE__;
+			push @{"$caller\::ISA"}, 'Crypt::Passphrase::Validator' unless $caller->isa('Crypt::Passphrase::Validator');
+			push @{"$caller\::CARP_NOT"}, __PACKAGE__, mro::get_linear_isa($caller);
 		}
 		elsif ($arg eq '-integration') {
 			push @CARP_NOT, $caller;
@@ -158,13 +160,13 @@ Crypt::Passphrase - A module for managing passwords in a cryptographically agile
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
  my $authenticator = Crypt::Passphrase->new(
      encoder    => 'Argon2',
-     validators => [ 'Bcrypt' ],
+     validators => [ 'Bcrypt', 'SHA1::Hex' ],
  );
 
  my ($hash) = $dbh->selectrow_array("SELECT password FROM users WHERE name = ?", {}, $user);
@@ -264,7 +266,7 @@ Hashing passwords is by its nature a heavy operations. It can be abused by malig
 
 In some situations, it may be appropriate to have different password settings for different users (e.g. set them more strict for administrators than for ordinary users).
 
-=head1 SEE ALSO
+=head1 BACKENDS
 
 The following encoders are currently available on CPAN:
 
@@ -294,8 +296,14 @@ An implementation of SHA-512, SHA256 and MD5 based C<crypt()>. Recommended if yo
 
 A first-generation memory-hard algorithm, Argon2 is recommended instead if you want a memory-hard algorithm.
 
+=item * L<Crypt::Passphrase::System|Crypt::Passphrase::System>
+
+Your system's C<crypt> implementation. Support for various algorithms varies between platforms and platform versions, and while on some platforms it's a good backend one should not rely on this for a portable result.
+
 =back
 
+=head1 INTEGRATIONS
+
 A number of integrations of Crypt::Passphrase exist:
 
 =over 4
